/***
GLobal Directives
***/

// Route State Load Spinner(used on page or content load)
MetronicApp.directive('ngSpinnerBar', ['$rootScope', '$state',
    function($rootScope, $state) {
        return {
            link: function(scope, element, attrs) {
                // by defult hide the spinner bar
                element.addClass('hide'); // hide spinner bar by default

                // display the spinner bar whenever the route changes(the content part started loading)
                $rootScope.$on('$stateChangeStart', function() {
                    element.removeClass('hide'); // show spinner bar
                });

                // hide the spinner bar on rounte change success(after the content loaded)
                $rootScope.$on('$stateChangeSuccess', function(event) {
                    element.addClass('hide'); // hide spinner bar
                    $('body').removeClass('page-on-load'); // remove page loading indicator
                    Layout.setAngularJsSidebarMenuActiveLink('match', null, event.currentScope.$state); // activate selected link in the sidebar menu
                   
                    // auto scorll to page top
                    setTimeout(function () {
                        App.scrollTop(); // scroll to the top on content load
                    }, $rootScope.settings.layout.pageAutoScrollOnLoad);     
                });

                // handle errors
                $rootScope.$on('$stateNotFound', function() {
                    element.addClass('hide'); // hide spinner bar
                });

                // handle errors
                $rootScope.$on('$stateChangeError', function() {
                    element.addClass('hide'); // hide spinner bar
                });
            }
        };
    }
])

// Handle global LINK click
MetronicApp.directive('a', function() {
    return {
        restrict: 'E',
        link: function(scope, elem, attrs) {
            if (attrs.ngClick || attrs.href === '' || attrs.href === '#') {
                elem.on('click', function(e) {
                    e.preventDefault(); // prevent link click for above criteria
                });
            }
        }
    };
});

// Handle Dropdown Hover Plugin Integration
MetronicApp.directive('dropdownMenuHover', function () {
  return {
    link: function (scope, elem) {
      elem.dropdownHover();
    }
  };  
});

MetronicApp.directive('selectOnClick',function ($window) {
    return {
        restrict: 'A',
        link: function (scope, element, attrs) {
            element.on('click', function () {
                if (!$window.getSelection().toString()) {
                    // Required for mobile Safari
                    this.setSelectionRange(0, this.value.length)
                }
            });
        }
    };
});

MetronicApp.directive('numberInput',function ($log) {
    return {
        restrict: 'A',
		require: 'ngModel',
		scope: {
			targetScope: '=ngModel'
		},		
        link: function (scope, element, attrs, ctrl) {
            element.on('change', function () {
				let input = element.val();console.log(input);
				let invalid = isNaN(input) || input == "";
				let output = invalid ? "" : Math.abs((parseFloat(input).toFixed(2)));
                // element.val(output);
				ctrl.$setViewValue(output);
				ctrl.$render();
            });
        }
    };
});

MetronicApp.directive('numberZerosInput',function ($log) {
    return {
        restrict: 'A',
        link: function (scope, element, attrs) {
            element.on('change', function () {
				let input = element.val();
				let invalid = isNaN(input) || input == "";
				let output = invalid ? "" : input;
                element.val(output);
            });
        }
    };
});

/* //Handle decimal inputs, allow number only, return 0.00 if isNaN
MetronicApp.directive('decimalInput',function ($log) {
    return {
        restrict: 'A',
		scope: {
			targetScope: '=ngModel'
		},
        link: function (scope, element, attrs) {
            element.on('change', function () {
				if(isNaN(scope.targetScope)){
					scope.targetScope = "0.00";
				} else {
					scope.targetScope = (parseFloat(scope.targetScope)).toFixed(2);
				}
				scope.$apply();
			});
        }
    };
}); */
/* return decimal value or 0.00 on blank & isNaN */
MetronicApp.directive('decimalInput',function ($log) {
    return {
        restrict: 'A',
		require: 'ngModel',
		scope: {
			targetScope: '=ngModel'
		},
        link: function (scope, element, attrs, ctrl) {
            element.on('change', function () {
				var output;
				if(isNaN(scope.targetScope) || scope.targetScope == ""){
					output = "0.00";
				} else {
					output = (parseFloat(scope.targetScope)).toFixed(2);
				}
				ctrl.$setViewValue(output);
				ctrl.$render();
			});
        }
    };
});
/* return decimal value or blank on blank & isNaN */
MetronicApp.directive('decimalBlankInput',function ($log) {
    return {
        restrict: 'A',
		require: 'ngModel',
		scope: {
			targetScope: '=ngModel'
		},
        link: function (scope, element, attrs, ctrl) {
            element.on('change', function () {
				var output;
				if(isNaN(scope.targetScope) || scope.targetScope == 0){
					output = "";
				} else {
					output = (parseFloat(scope.targetScope)).toFixed(2);
				}
					ctrl.$setViewValue(output);
					ctrl.$render();
			});
        }
    };
});
//Handle quantity(integer) inputs, allow number only, return 0 if isNaN
MetronicApp.directive('qtyInput',function ($log) {
    return {
        restrict: 'A',
		scope: {
			targetScope: '=ngModel'
		},
        link: function (scope, element, attrs) {
            element.on('change', function () {
				if(isNaN(scope.targetScope)){
					console.log(scope);
					scope.targetScope = "0";
					scope.$apply();
				}
			});
        }
    };
});

MetronicApp.directive('discountInput',function ($log) {
    return {
        restrict: 'A',
		require: 'ngModel',
		scope: {
			targetScope: '=ngModel'
		},
        link: function (scope, element, attrs, ctrl) {
            element.on('change', function () {
				
				var input = scope.targetScope;
				if(input.length == 0){
					output = "0.00";
				} else {
					var sign =  input.substr(input.length-1);
					var number = input.slice(0,input.length-1);
					var isRate = (sign === "%") && !isNaN(number);
					var output;
					
					if(!isNaN(input) || isRate){
						output = isRate ?  (parseFloat(number)).toFixed(2)+"%" : (parseFloat(input)).toFixed(2);
						
					} else {
						output = "0.00";
					}
				}

				//scope.$apply();
				ctrl.$setViewValue(output);
				ctrl.$render();
				// scope.targetScope = output;
				// scope.$apply();
			});
        }
    };
});

//angular.module('MetronicApp').directive('fileModel', function($parse) {
MetronicApp.directive('fileModel', function($parse) {
   return {
      restrict: 'A',
      link: function(scope, element, attrs) {
         var model = $parse(attrs.fileModel);
         var modelSetter = model.assign;
         
         element.bind('change', function(){
            scope.$apply(function(){
               modelSetter(scope, element[0].files[0]);
            });
         });
      }
   };
});