/***
Metronic AngularJS App Main Script
***/

/* Metronic App */
var MetronicApp = angular.module("MetronicApp", [
    "ui.router", 
    "ui.bootstrap", 
    "oc.lazyLoad",  
    "ngSanitize",
    "ngCookies",
    'toastr',
	"angucomplete-alt",
	"userData"
]); 


/* Configure ocLazyLoader(refer: https://github.com/ocombe/ocLazyLoad) */
MetronicApp.config(['$ocLazyLoadProvider', function($ocLazyLoadProvider) {
    $ocLazyLoadProvider.config({
        // global configs go here
    });
}]);

//AngularJS v1.3.x workaround for old style controller declarition in HTML
MetronicApp.config(['$controllerProvider', function($controllerProvider) {
  // this option might be handy for migrating old apps, but please don't use it
  // in new ones!
  $controllerProvider.allowGlobals();
}]);

MetronicApp.config(function(toastrConfig) {
  angular.extend(toastrConfig, {
    allowHtml: true,
    closeButton: true,
    closeHtml: '<button>&times;</button>',
    maxOpened: 0,
    extendedTimeOut: 500,
    iconClasses: {
      error: 'toast-error',
      info: 'toast-info',
      success: 'toast-success',
      warning: 'toast-warning'
    },  
    messageClass: 'toast-message',
    onHidden: null,
    onShown: null,
    onTap: null,
    progressBar: false,
	preventDuplicates: false,

	tapToDismiss: false,
    templates: {
	  toast: 'directives/toast/toast.html',
	  progressbar: 'directives/progressbar/progressbar.html'
	},
    timeOut: 5000,
    titleClass: 'toast-title',
    toastClass: 'toast'
  });
});
/********************************************
 END: BREAKING CHANGE in AngularJS v1.3.x:
*********************************************/

/* Setup global settings */
MetronicApp.factory('settings', ['$rootScope', function($rootScope) {
    // supported languages
    var settings = {
        layout: {
            pageSidebarClosed: false, // sidebar menu state
            pageContentWhite: true, // set page content layout
            pageBodySolid: false, // solid body color state
            pageAutoScrollOnLoad: 1000 // auto scroll to top on page load
        },
        assetsPath: '../assets',
        globalPath: '../assets/global',
        layoutPath: '../assets/layouts/app',
    };
    $rootScope.settings = settings;
	$rootScope.uploadPayment = 0;
    return settings;
}]);

/* Setup global custom filters */
/* serach object with multiple fields */
MetronicApp.filter('multiFields',function(){
	return function(searchArray,searchString,searchFields){
		if(searchString.length == 0){
			return searchArray;
		}
		var output = [];
		for(var i in searchArray){
			for(var k in searchFields){
				var keyString = searchFields[k].indexOf(".") > 0 ? searchFields[k].split(".") : searchFields[k];
				var reference = (typeof keyString === "string") ? searchArray[i][keyString] : extractArray(keyString,searchArray[i]);
				//if the reference is empty skip to next search key
				if(reference == null){
					continue;
				}
				//if number , parse to string
				reference = typeof reference === "number" ? reference.toString() : reference;
				if(reference.indexOf(searchString) > -1){
					output.push(searchArray[i]);
					break;
				}
			}
		}
		return output;
	};
	/* extract value from multi-dimenssional array */
	function extractArray(needle, haystack){
		var objName = "haystack";
		for(let i in needle){
			objName += "['"+needle[i]+"']";
		}
		return eval(objName);
	}
});

/* Setup App Main Controller */
MetronicApp.controller('AppController', function($window, $scope, $state, $rootScope, $stateParams, $http, $cookies, $sessionService, userData) {


	$http.defaults.headers.common["X-Requested-With"] = "XMLHttpRequest";
	$http.defaults.headers.common["X-Requested-By"] = "MCFApplication";
	
	// To disable f5
		/* jQuery < 1.7 */	
	$(document).bind("keydown", disableF5);
	/* OR jQuery >= 1.7 */
	$(document).on("keydown", disableF5);
	/* get userData  */
	for(var prop in userData.scope){
		$scope[prop] = userData.scope[prop];
	}
	for(var prop in userData.rootScope){
		$rootScope[prop] = userData.rootScope[prop];
	}
	for(var prop in userData.stateParams){
		$stateParams[prop] = userData.stateParams[prop];
	}
	$rootScope.sessionUserData = $scope.sessionUserData;
	var menuType = $stateParams.menuType;
	var lv1Menu = $stateParams.lv1Menu;
	$scope.state = $state.current;
	$scope.params = $stateParams;
	$scope.showPricing = true;
	$scope.showPayment = false;
	$scope.showCash = false;
	$scope.showSuccess = false;
	$scope.selectedPrice = 1;
	$scope.chkShowTax = "none";
	$scope.copyAddress = false;
	$scope.sa = {};
	$scope.ba = {};
	$scope.update = function(sa) {
		scope.ba = angular.copy(scope.sa);
	};
	
	$scope.pricingMenu = {
		1 : {
			price: '7,500',
		average: 7500/12,
			period: '1 Year',
			bonus: 'พิเศษ!! สัมมนาออนไลน์',
		membership_id : 4
		},
		2 : {
			price: '25,000',
		average: '2084',
			period: '1 Year',
			bonus: 'พิเศษ!! สัมมนาออนไลน์',
		membership_id : 5
		}
	};		
	//// To re-enable f5
	//    /* jQuery < 1.7 */
	//$(document).unbind("keydown", disableF5);
	// /* OR jQuery >= 1.7 */
	//$(document).off("keydown", disableF5);
	//$tmp = $sessionService.test().then(function(dat){console.log(dat);});

	/* slight update to account for browsers not supporting e.which */
	function disableF5(e) {
		if (e.keyCode == 116) {
			e.preventDefault();
			var refreshUrl = "http://"+window.location.host+"/cdn/app/#"+$state.current.url;
			console.log(refreshUrl);
			e.preventDefault();
			$window.location.reload();
		}
	};
	
	$scope.$on('$viewContentLoaded', function() {

        //App.initComponents(); // init core components
        //Layout.init(); //  Init entire layout(header, footer, sidebar, etc) on page load if the partials included in server side instead of loading with ng-include directive      
		$scope.uploadFile = function(files) {
			//console.log($scope.validatePaymentData);
			var fd = new FormData();
			fd.append("fileUpload", files[0]);
			$scope.pictureUpload = files[0];
			$scope.validatePaymentData = 1;
			$(".submit-cash").prop('disabled',false);
			checkTextValidate();
		}

		$(".validate_text").on("keyup",(function(event){ 
				checkTextValidate(); 
		}));
		
		
		$(".validate_text").on("blur",(function(event){ 
				checkTextValidate(); 
		}));
		
		
		$("#chkcopyAddress").on("click",(function(event){ 
				checkTextValidate(); 
		}));
		
		$(".area_tax_addr").on("keyup",(function(event){ 
			$('#payment input[name="tax_addr_send"]').val($(".area_tax_addr").val());
		}));
	  
		function checkTextValidate(){
					
			var isEmpty = false;
				$(".validate_text").each(function(){
					if($(this).val() === ""){
						isEmpty = true;
					}
				});
				
				if($("#fileUpload").val() === ""){
					isEmpty = true; 
				}
				
				$(".submit-cash").prop('disabled',isEmpty); 
			
		}
	  
	
		$(".submit-cash").on("click",function(event){
			event.preventDefault;
			if($rootScope.uploadPayment == 0 && $scope.validatePaymentData == 1 )
			{
				
					var formData = new FormData();
					var picUpload = $scope.pictureUpload;
					formData.append("fileUpload", picUpload);
					formData.append("membership_business_id", $('#payment input[name="membership_business_id"]').val());
					formData.append("business_user_id", $('#payment input[name="business_user_id"]').val());
					formData.append("membership_package_id", $('#payment input[name="membership_package_id"]').val());
					formData.append("usr_bank", $('#payment input[name="usr_bank"]:checked').val());
					formData.append("usr_amount", $('#payment input[name="usr_amount"]').val());
					formData.append("membership_amount", $('#payment input[name="membership_amount"]').val());
					formData.append("usr_date", $('#payment input[name="usr_date"]').val());
					formData.append("usr_time", $('#payment input[name="usr_time"]').val());
					//formData.append("usr_time", "12:00");
					formData.append("tax_name", $('#payment input[name="tax_name"]').val());
					formData.append("tax_no", $('#payment input[name="tax_no"]').val());
					formData.append("tax_branch", $('#payment input[name="tax_branch"]').val());
					//formData.append("tax_addr", $('#payment input[name="tax_addr"]').val());
					formData.append("tax_addr", $('.area_text').val());
					
					formData.append("tax_addr_send", $('#payment input[name="tax_addr_send"]').val());
					 
					 $http.post('php_data/insertPayment.php', formData, {
							withCredentials: true,
							headers: {'Content-Type': undefined },
							transformRequest: angular.identity
					 }).success(function(data){
						if(data.success)
						{ 
							$scope.showCash = false;
							//$scope.showSuccess = true;
							$(".submit-cash").prop('disabled',true);
							$scope.validatePaymentData = 1;
							var updateData = { 'business_id' : 1, 'user_name' : $scope.sessionUserData.userName, 'user_id' : $scope.sessionUserData.userId, 'payment_pending' : 1};
							$http.post('php_data/updatePaymentPending.php?business_id=1&user_name='+$scope.sessionUserData.userName+'&user_id='+$scope.sessionUserData.userId+'&payment_pending=1')
							.success(function(result){
								$scope.validatePaymentData = 0;
								//console.log(result);
							}).error(function(errResult) {
								console.log(errResult);
							});
						}
						else
						{
							alert('error');
						}
					 } ).error( function(errRes){
						console.log(errRes); 
					 }  );
				 
					
			}
			else
			{
				$scope.validatePaymentData = 0;
				console.log('Error.Please check that you have attached your file properly.');
			}
				
		});
		
		$scope.refreshScope = function() {
			window.location.reload();
		}
		
		Date.prototype.toDateInputValue = (function(date) {
			var local = new Date(this);
			var newDate = ("0"+(local.getDate())).slice(-2)+"-"+("0"+(local.getMonth()+1)).slice(-2)+"-"+local.getFullYear();
			return newDate;
		});
		
		$scope.transfer = {
			date : new Date().toDateInputValue()
		};
		
		$('.date-picker').each(function() {
			var elem = $(this);
			if(!elem.hasClass('payment-upgrade-date'))
			{
				elem.bind("focus onkeydown onpaste oncut ", function(event){
				elem.data('oldVal', elem.val());
				if(elem.data('oldVal') == "")
				{
					$('.date-picker').val((new Date()).toDateInputValue(""));
				}
				});
				elem.bind("blur", function(event){
				if(elem.val() == "")
				{
					$('.date-picker').val((new Date()).toDateInputValue(""));
				}
				});
			}	
		});
		//var startDateTemp = (new Date().toDateInputValue(""));
		//var endtDateTemp = (new Date().toDateInputValue(""));
		$scope.report = {
			startDate : null,
			endDate : null
		}
		$('.input-daterange input[name="from"]').bind("focus onkeydown onpaste oncut ",function() {
			if($(this).val() !== null)
			{
				$scope.report.startDate = ($(this).val());
			}
			else
			{
				$scope.report.startDate = (new Date().toDateInputValue(""));
			}
		});	
		
		$('.input-daterange input[name="from"]').bind("blur ",function() {
			if($(this).val() == "")
			{
				$scope.report.startDate = (new Date().toDateInputValue(""));
				$('.input-daterange input[name="from"]').val(new Date().toDateInputValue(""));
			}
		});
		
		$('.input-daterange input[name="to"]').bind("focus onkeydown onpaste oncut ",function() {
			if($(this).val() !== null)
			{
				$scope.report.endDate = ($(this).val());
			}
			else
			{
				$scope.report.endDate = (new Date().toDateInputValue(""));
			}
		});	
		
		$('.input-daterange input[name="to"]').bind("blur ",function() {
			if($(this).val() == "")
			{
				$scope.report.endDate = (new Date().toDateInputValue(""));
				$('.input-daterange input[name="to"]').val(new Date().toDateInputValue(""));
			}
		});
		
	});

});

/***
Layout Partials.
By default the partials are loaded through AngularJS ng-include directive. In case they loaded in server side(e.g: PHP include function) then below partial 
initialization can be disabled and Layout.init() should be called on page load complete as explained above.
***/

/* Setup Layout Part - Header */
MetronicApp.controller('HeaderController',  function($rootScope, $scope, $state, $dbService) {
    $scope.$on('$includeContentLoaded', function() {
        Layout.initHeader(); // init header
    });
});

/* Setup Layout Part - Sidebar */
MetronicApp.controller('SidebarController', ['$state', '$scope', function($state, $scope) {
    $scope.$on('$includeContentLoaded', function() {
        Layout.initSidebar($state); // init sidebar
    });
}]);

/* Setup Choose Module 
MetronicApp.controller('ChooseModule', ['$state', '$scope',"$cookies", function($state, $scope, $cookies) {
    $scope.$on('$includeContentLoaded', function() {

    	$scope.setModule = function(moduleName)
    	{
    			$scope.chosenModule = moduleName;
    			$cookies.put('mcf_chosen_module',moduleName);
    			window.location.reload();
    	}
    });
}]);
*/

/* Setup Layout Part - Sidebar */
MetronicApp.controller('PageHeadController', ['$scope', 'settings',function($scope,settings) {
    $scope.$on('$includeContentLoaded', function() {   

        //Demo.init(); // init theme panel
    });
	$scope.coupon = {
        show: true,
        code: "" ,
        valid: false,
        validate: function(input){
            var isValid = input.length > 3 ? true : false;
            this.valid = isValid;
        }
    };
}]);

/* Setup Layout Part - Quick Sidebar */
MetronicApp.controller('QuickSidebarController', ['$scope', function($scope) {    
    $scope.$on('$includeContentLoaded', function() {
       setTimeout(function(){
            QuickSidebar.init(); // init quick sidebar        
        }, 2000)
    });
}]);

/* Setup Layout Part - Theme Panel */
MetronicApp.controller('ThemePanelController', ['$scope', function($scope) {    
    $scope.$on('$includeContentLoaded', function() {
        Demo.init(); // init theme panel
    });
}]);

/* Setup Layout Part - Footer */
MetronicApp.controller('FooterController', ['$scope', function($scope) {
    $scope.$on('$includeContentLoaded', function() {
        Layout.initFooter(); // init footer
    });
}]);

/* Setup Rounting For All Pages */
MetronicApp.config(['$stateProvider', '$urlRouterProvider', function($stateProvider, $urlRouterProvider) {
    // Redirect any unmatched url
    $urlRouterProvider.otherwise("/home");  

    $stateProvider

	    // Expired
        .state('expired', {
            url: "/expired",
            templateUrl: "views/expired.html",            
            data: {pageTitle: 'แพ็กเกจหมดอายุ'}
            //,controller: "ExpiredMainCtl"
        })
	
	    // Home
        .state('home', {
            url: "/home",
            templateUrl: "tpl/choose_module.html",   
            data: {pageTitle: 'MY CashFlow', module:'home', main_module: 'home', headerTitle: 'หน้าหลัก'}
        })	
        // Dashboard
   //     .state('home', {
 //           url: "/home",
        .state('dashboard', {
            url: "/dashboard",
            templateUrl: "views/dashboard.html",            
            data: {pageTitle: 'MY CashFlow', module:'dashboard' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "DashboardController",
           // authenticate: true,
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/global/plugins/morris/morris.css',                            
                            '../assets/global/plugins/morris/morris.min.js',
                            '../assets/global/plugins/morris/raphael-min.js',                            
                            '../assets/global/plugins/jquery.sparkline.min.js',
                            '../assets/global/plugins/highcharts.js',
                            '../assets/pages/scripts/dashboard.min.js',
                            'js/controllers/DashboardController.js',
                        ] 
                    });
                }],
                $sumData: function($getQuery){
                    return $getQuery.getCashFlowSummary();
                }
            }
        })
        // Revenue
        .state('revenue', {
            url: "/revenue",
            templateUrl: "views/revenue/main.html",            
            data: {pageTitle: 'รับเงิน', iClass: 'icon-plus' , module:'revenue' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "RevenueMainCtrl",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/apps/scripts/revenue.js',
                            'js/controllers/RevenueMainCtrl.js',
                        ]
                    });
                }],
				$categorySummary: function($getQuery){
                    return $getQuery.getAmount('','',1,4);
                }
            }
        })
         // Revenue-manage
        .state('revenue-operating-main', {
            url: "/revenue/operating/:lv1Menu?menuType",
            templateUrl: "views/revenue/operating/manage.html",            
            data: {pageTitle: 'รับเงิน', iClass: 'icon-plus', module:'revenue-operating-main' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "RevenueManageCtrl",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            
                            'js/controllers/RevenueManageCtrl.js',
                        ] 
                    });
                }],
                $rcvMenus: function($getQuery){
                    return $getQuery.getMenus('rcv');
                },
                $debtorAccounts: function($getQuery){
                    return $getQuery.getAccounts('rcv');
                },
				$creditorAccounts: function($getQuery){
                    return $getQuery.getAccounts('exp');
                }
            }
        })
          // Revenue-history
        .state('revenue-operating-history', {
            url: "/revenue/operating/history/:lv1Menu?menuType",
            templateUrl: "views/revenue/operating/history.html",            
            data: {pageTitle: 'รับเงิน', iClass: 'icon-plus', module:'revenue-operating-history' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "RevenueHistoryCtrl",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/global/plugins/datatables/datatables.min.css', 
                            '../assets/global/plugins/datatables/plugins/bootstrap/datatables.bootstrap.css',
                            '../assets/global/plugins/datatables/datatables.all.min.js',
                            '../assets/global/scripts/datatable.min.js',
                            //'js/scripts/revenue-operating-history.js',
                            'js/controllers/RevenueHistoryCtrl.js',
                        ] 
                    });
                }],
                $rcvMenus: function($getQuery){
                    return $getQuery.getMenus('rcv');
                },
                $rcvTrans: function($getQuery){
                    return $getQuery.getTrans('rcv');
                }
            }
        })
        // Expense
        .state('expense', {
            url: "/expense",
            templateUrl: "views/expense/main.html",            
            data: {pageTitle: 'จ่ายเงิน', iClass: 'icon-minus', module:'expense' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "ExpenseMainCtrl",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/global/plugins/morris/morris.css',                            
                            '../assets/global/plugins/morris/morris.min.js',
                            '../assets/global/plugins/morris/raphael-min.js',                            
                            '../assets/global/plugins/jquery.sparkline.min.js',
                            '../assets/pages/scripts/dashboard.min.js',
                            'js/controllers/ExpenseMainCtrl.js',
                        ] 
                    });
                }],
				$categorySummary: function($getQuery){
                    return $getQuery.getAmount('','',1,4);
                }
            }
        })
         // Expense-manage
        .state('expense-operating-main', {
            url: "/expense/operating/:lv1Menu?menuType",
            templateUrl: "views/expense/operating/manage.html",            
            data: {pageTitle: 'จ่ายเงิน', iClass: 'icon-minus', module:'expense-operating-main' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "ExpenseManageCtrl",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/ExpenseManageCtrl.js',
                        ] 
                    });
                }],
                $expMenus: function($getQuery){
                    return $getQuery.getMenus('exp');
                },
                $creditorAccounts: function($getQuery){
                    return $getQuery.getAccounts('exp');
                }
            }
        })
         // Revenue-history
        .state('expense-operating-history', {
            url: "/expense/operating/history/:lv1Menu?menuType",
            templateUrl: "views/expense/operating/history.html",            
            data: {pageTitle: 'จ่ายเงิน', iClass: 'icon-minus', module:'expense-operating-history' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "ExpenseHistoryCtrl",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/global/plugins/datatables/datatables.min.css', 
                            '../assets/global/plugins/datatables/plugins/bootstrap/datatables.bootstrap.css',
                            '../assets/global/plugins/datatables/datatables.all.min.js',
                            //'js/scripts/expense-operating-history.js',
                            'js/controllers/ExpenseHistoryCtrl.js',
                        ] 
                    });
                }],
                $expMenus: function($getQuery){
                    return $getQuery.getMenus('exp');
                },
                $expTrans: function($getQuery){
                    return $getQuery.getTrans('exp');
                }
            }
        })
        // Creditor
        .state('creditor', {
            url: "/creditor",
            templateUrl: "views/creditor/main.html",            
            data: {pageTitle: 'กำหนดจ่ายเงิน', iClass: 'icon-user iminus', module:'creditor' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "CreditorMainCtrl",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/global/plugins/morris/morris.css',                            
                            '../assets/global/plugins/morris/morris.min.js',
                            '../assets/global/plugins/morris/raphael-min.js',                            
                            '../assets/global/plugins/jquery.sparkline.min.js',
                            '../assets/pages/scripts/dashboard.min.js',
                            'js/controllers/CreditorMainCtrl.js'
                        ] 
                    });
                }],
                $lv3Menus: function($getQuery){
                    return $getQuery.getLv3Menus('exp');
                },
                $creditors: function($getQuery){
                    return $getQuery.getAccounts('exp');
                }
            }
        })
        .state('creditor-edit', {
            url: "/creditor/edit",
            templateUrl: "views/creditor/edit.html",            
            data: {pageTitle: 'กำหนดจ่ายเงิน', iClass: 'icon-user iminus', module:'creditor-edit' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "CreditorEditCtrl",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/global/plugins/morris/morris.css',                            
                            '../assets/global/plugins/morris/morris.min.js',
                            '../assets/global/plugins/morris/raphael-min.js',                            
                            '../assets/global/plugins/jquery.sparkline.min.js',
                            '../assets/global/plugins/datatables/plugins/bootstrap/datatables.bootstrap.css',
                            '../assets/pages/scripts/dashboard.min.js',
                            'js/controllers/CreditorEditCtrl.js'
                        ] 
                    });
                }],
                $expMenus: function($getQuery){
                    return $getQuery.getMenus('exp');
                },
                $advExpTrans: function($getQuery){
                    return $getQuery.getAdvTrans('exp');
                }
            }
        })
        // Debtor
        .state('debtor', {
            url: "/debtor",
            templateUrl: "views/debtor/main.html",            
            data: {pageTitle: 'กำหนดรับเงิน', iClass: 'icon-user iplus', module:'debtor' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "DebtorMainCtrl",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/global/plugins/morris/morris.css',                            
                            '../assets/global/plugins/morris/morris.min.js',
                            '../assets/global/plugins/morris/raphael-min.js',                            
                            '../assets/global/plugins/jquery.sparkline.min.js',

                            '../assets/pages/scripts/dashboard.min.js',
                            'js/controllers/DebtorMainCtrl.js',
                        ] 
                    });
                }],
                $lv3Menus: function($getQuery){
                    return $getQuery.getLv3Menus('rcv');
                },
                $debtors: function($getQuery){
                    return $getQuery.getAccounts('rcv');
                },
				$creditors: function($getQuery){
                    return $getQuery.getAccounts('exp');
                }
            }
        })
        .state('debtor-edit', {
            url: "/debtor/edit",
            templateUrl: "views/debtor/edit.html",            
            data: {pageTitle: 'กำหนดรับเงิน', iClass: 'icon-user iplus', module:'debtor-edit' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "DebtorEditCtrl",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/global/plugins/morris/morris.css',                            
                            '../assets/global/plugins/morris/morris.min.js',
                            '../assets/global/plugins/morris/raphael-min.js',                            
                            '../assets/global/plugins/jquery.sparkline.min.js',
                            '../assets/global/plugins/datatables/plugins/bootstrap/datatables.bootstrap.css',
                            '../assets/pages/scripts/dashboard.min.js',
                            'js/controllers/DebtorEditCtrl.js',
                        ] 
                    });
                }],
                $rcvMenus: function($getQuery){
                    return $getQuery.getMenus('rcv');
                },
                $advRcvTrans: function($getQuery){
                    return $getQuery.getAdvTrans('rcv');
                }
            }
        })
        // Report
        .state('report', {
            url: "/report",
            templateUrl: "views/report/main.html",            
            data: {pageTitle: 'รายงาน', iClass: 'icon-chart', module:'report' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "ReportController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/global/plugins/morris/morris.css',                            
                            '../assets/global/plugins/morris/morris.min.js',
                            '../assets/global/plugins/morris/raphael-min.js',                            
                            '../assets/global/plugins/jquery.sparkline.min.js',

                            '../assets/pages/scripts/dashboard.min.js',
                            'js/controllers/ReportController.js',
                        ] 
                    });
                }]
            }
        })
      .state('cashflow-table', {
            url: "/report/cashflow-table",
            templateUrl: "views/report/cashflow-table.html",            
            data: {pageTitle: 'รายงาน', iClass: 'icon-chart', module:'cashflow-table'  , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "ReportCashFlowTableController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
					    '../assets/global/plugins/js-xlsx/dist/xlsx.full.min.js',
                            '../assets/global/plugins/datatables/datatables.min.css', 
                            '../assets/global/plugins/datatables/plugins/bootstrap/datatables.bootstrap.css',
                            '../assets/global/plugins/bootstrap-datepicker/css/bootstrap-datepicker3.min.css',
                            '../assets/global/plugins/datatables/datatables.all.min.js',
                            '../assets/global/plugins/file-saver.js',
                            '../assets/pages/scripts/components-date-time-pickers.js',
                            '../assets/pages/scripts/table-datatables-managed.js',
                            'js/controllers/ReportCashFlowTableController.js',
                        ] 
                    });
                }]
            }
        })
	   .state('cashflow-compare', {
            url: "/report/cashflow-compare",
            templateUrl: "views/report/cashflow-compare.html",            
            data: {pageTitle: 'รายงานเปรียบเทียบ', iClass: 'icon-chart', module:'cashflow-table' , main_module: 'mcf', headerTitle : 'กระแสเงินสด' },
            controller: "ReportCashFlowCompareController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/global/plugins/js-xlsx/dist/xlsx.full.min.js',
                            '../assets/global/plugins/datatables/datatables.min.css', 
                            '../assets/global/plugins/datatables/plugins/bootstrap/datatables.bootstrap.css',
                            '../assets/global/plugins/bootstrap-datepicker/css/bootstrap-datepicker3.min.css',
                            '../assets/global/plugins/datatables/datatables.all.min.js',
                            '../assets/global/plugins/file-saver.js',
                            '../assets/pages/scripts/components-date-time-pickers.js',
                            '../assets/pages/scripts/table-datatables-managed.js',
                            'js/controllers/ReportCashFlowCompareController.js',
                        ] 
                    });
                }]
            }
        })
        .state('cashflow-graph', {
            url: "/report/cashflow-graph",
            templateUrl: "views/report/cashflow-graph.html",            
            data: {pageTitle: 'รายงาน', iClass: 'icon-chart', module:'cashflow-graph' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "ReportCashFlowGraphController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            
                            '../assets/global/plugins/datatables/datatables.min.css', 
                            '../assets/global/plugins/datatables/plugins/bootstrap/datatables.bootstrap.css',
                            '../assets/global/plugins/bootstrap-datepicker/css/bootstrap-datepicker3.min.css',
                            '../assets/global/plugins/datatables/datatables.all.min.js',
                            '../assets/pages/scripts/components-date-time-pickers.js',
                            '../assets/pages/scripts/table-datatables-managed.js',
                            '../assets/global/plugins/highcharts.js',
                            'js/controllers/ReportCashFlowGraphController.js',
                        ] 
                    });
                }]
            }
        })
        .state('creditor-table', {
            url: "/report/creditor-table",
            templateUrl: "views/report/creditor-table.html",            
            data: {pageTitle: 'รายงาน', iClass: 'icon-chart', module:'creditor-table' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "ReportCreditorTableController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            
                            '../assets/global/plugins/datatables/datatables.min.css', 
                            '../assets/global/plugins/datatables/plugins/bootstrap/datatables.bootstrap.css',
                            '../assets/global/plugins/bootstrap-datepicker/css/bootstrap-datepicker3.min.css',
                            '../assets/global/plugins/datatables/datatables.all.min.js',
                            '../assets/pages/scripts/components-date-time-pickers.js',
                            '../assets/pages/scripts/table-datatables-managed.js',
                            'js/controllers/ReportCreditorTableController.js',
                        ] 
                    });
                }],
                $accData: function($getQuery){
                    var date = new Date();
	                var firstDayTemp = new Date(date.getFullYear(), date.getMonth(), 1);
	                var firstDay = ("0"+(firstDayTemp.getDate())).slice(-2)+"-"+("0"+(firstDayTemp.getMonth()+1)).slice(-2)+"-"+firstDayTemp.getFullYear();
	                var lastDayTemp = new Date(date.getFullYear(), date.getMonth() + 1, 0);
	                var lastDay = ("0"+(lastDayTemp.getDate())).slice(-2)+"-"+("0"+(lastDayTemp.getMonth()+1)).slice(-2)+"-"+lastDayTemp.getFullYear();
                    return $getQuery.getAccDataSum(firstDay,lastDay,'exp');
                }
            }
        })
        .state('debtor-table', {
            url: "/report/debtor-table",
            templateUrl: "views/report/debtor-table.html",            
            data: {pageTitle: 'รายงาน', iClass: 'icon-chart', module:'debtor-table' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "ReportDebtorTableController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            
                            '../assets/global/plugins/datatables/datatables.min.css', 
                            '../assets/global/plugins/datatables/plugins/bootstrap/datatables.bootstrap.css',
                            '../assets/global/plugins/bootstrap-datepicker/css/bootstrap-datepicker3.min.css',
                            '../assets/global/plugins/datatables/datatables.all.min.js',
                            '../assets/pages/scripts/components-date-time-pickers.js',
                            '../assets/pages/scripts/table-datatables-managed.js',
                            'js/controllers/ReportDebtorTableController.js',
                        ] 
                    });
                }],
                $accData: function($getQuery){
                    var date = new Date();
	                var firstDayTemp = new Date(date.getFullYear(), date.getMonth(), 1);
	                var firstDay = ("0"+(firstDayTemp.getDate())).slice(-2)+"-"+("0"+(firstDayTemp.getMonth()+1)).slice(-2)+"-"+firstDayTemp.getFullYear();
	                var lastDayTemp = new Date(date.getFullYear(), date.getMonth() + 1, 0);
	                var lastDay = ("0"+(lastDayTemp.getDate())).slice(-2)+"-"+("0"+(lastDayTemp.getMonth()+1)).slice(-2)+"-"+lastDayTemp.getFullYear();
                    return $getQuery.getAccDataSum(firstDay,lastDay,'rcv');
                }
            }
        })
        // Class
        .state('class', {
            url: "/class",
            templateUrl: "views/class/main.html",            
            data: {pageTitle: 'ห้องเรียน', iClass: 'icon-social-youtube', module:'class' , main_module: 'class', headerTitle : 'ห้องเรียน'},
            controller: "ClassController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
						'../assets/global/plugins/angucomplete/angucomplete-alt.js',
                            'js/controllers/ClassController.js',
                        ] 
                    });
                }]
            }
        })
        // Settings
        .state('settings', {
            url: "/settings",
            templateUrl: "views/settings/main.html",            
            data: {pageTitle: 'ตั้งค่า', module:'settings' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "SettingsController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/global/plugins/bootstrap-fileinput/bootstrap-fileinput.css',
                            '../assets/global/plugins/jquery.sparkline.min.js',
                            '../assets/global/plugins/bootstrap-fileinput/bootstrap-fileinput.js',
                            'js/controllers/SettingsController.js'
                        ] 
                    });
                }]
            }
        })
        .state("settings.personal", {
            url: "/personal",
            templateUrl: "views/settings/personal.html",
			controller: 'SettingsPersonalCtrl',
            data: {pageTitle: 'ข้อมูลกิจการ', module:'settings-personal' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/SettingsPersonalCtrl.js'
                        ] 
                    });
                }],
				$personal: function($getQuery){
                    return $getQuery.getPersonal('1');
                }
            }
        })

        .state("settings.users", {
            url: "/users",
            templateUrl: "views/settings/users.html",
			controller: 'SettingsUsersCtrl',
            data: {pageTitle: 'จัดการพนักงาน', module:'settings-users' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            //'../assets/global/plugins/cryptoJS/components/core-min.js',
                            //'../assets/global/plugins/cryptoJS/components/md5.js',
                            'js/controllers/SettingsUsersCtrl.js'
                        ] 
                    });
                }],
				$users: function($getQuery){
                    return $getQuery.getUsers('1');
                }
            }
        })

        .state("settings.revenue", {
            url: "/revenue",
            templateUrl: "views/settings/revenue-setting.html",
            controller: 'SettingsRevenueCtrl',
            data: {pageTitle: 'จัดการหมวดหมู่รับ', module:'settings-revenue' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/SettingsRevenueCtrl.js'
                        ] 
                    });
                }],
                $menus: function($getQuery){
                    return $getQuery.getMenus('rcv','settings');
                }
            }
        })

        .state("settings.expense", {
            url: "/expense",
            templateUrl: "views/settings/expense-setting.html",
            controller: 'SettingsExpenseCtrl',
            data: {pageTitle: 'จัดการหมวดหมู่จ่าย', module:'settings-expense' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/SettingsExpenseCtrl.js'
                        ] 
                    });
                }],
                $menus: function($getQuery){
                    return $getQuery.getMenus('exp','settings');
                }
            }
        })

        .state("settings.debtor", {
            url: "/debtor",
            templateUrl: "views/settings/debtor.html",
            controller: 'SettingsDebtorCtrl',
            data: {pageTitle: 'จัดการบัญชีลูกหนี้', module:'settings-debtor' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/SettingsDebtorCtrl.js'
                        ] 
                    });
                }],
                $debtors: function($getQuery){
                    return $getQuery.getAccounts('rcv');
                }
            }
        })

        .state("settings.creditor", {
            url: "/creditor",
            templateUrl: "views/settings/creditor.html",
            controller: 'SettingsCreditorCtrl',
            data: {pageTitle: 'จัดการบัญชีเจ้าหนี้', module:'settings-creditor' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/SettingsCreditorCtrl.js'
                        ] 
                    });
                }],
                $creditors: function($getQuery){
                    return $getQuery.getAccounts('exp');
                }
            }
		})

		.state("settings.notification", {
            url: "/notification",
            templateUrl: "views/settings/notification.html",
			controller: 'SettingsNotificationlCtrl',
            data: {pageTitle: 'การแจ้งเตือน', module:'settings-notification' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/SettingsNotificationlCtrl.js'
                        ] 
                    });
                }],
				$personal: function($getQuery){
                    return $getQuery.getPersonal('1');
                }
            }
        })
		
		//Report settings
		.state("settings.reports", {
            url: "/reports",
            templateUrl: "views/settings/reports.html",
			controller: 'SettingsReportsCtrl',
            data: {pageTitle: 'การแสดงรายงาน', module:'settings-reports' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/SettingsReportsCtrl.js'
                        ] 
                    });
                }],
				$personal: function($getQuery){
                    return $getQuery.getPersonal('1');
                },
				$reportSettings: function($getQuery){
                    return $getQuery.getReportSettings();
                }
            }
        })
		/* ph2.1 */
		/* Invoice Dashboard */
		.state("invoice-dashboard", {
            url: "/invoice/dashboard",
            templateUrl: "views/invoice/dashboard.html",
			controller: 'InvoiceDashboardCtrl',
            data: {pageTitle: 'ภาพรวม', module:'invoice-dashboard' , main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/global/plugins/highcharts.js',
                            '../assets/pages/scripts/dashboard.min.js',
                            'js/controllers/InvoiceDashboardCtrl.js'
                        ] 
                    });
                }],
				defaultReportDashboard: function($getQuery){
					return $getQuery.getInvoiceDashboard(5);
				}
            }
        })
		/* Invoice Settings */
		.state("invoice-settings", {
            url: "/invoice/settings",
            templateUrl: "views/settings/invoice.html",
			controller: 'SettingsInvoiceCtrl',
            data: {pageTitle: 'ตั้งค่าการออกเอกสาร', module:'settings-invoice' , main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/SettingsInvoiceCtrl.js'
                        ] 
                    });
                }],
				userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}
            }
        })
		/* Invoice Settings - Documents Info */
		.state("invoice-settings.invoice-documents-info", {
            url: "/invoice/doc-info",
            templateUrl: "views/settings/invoice-documents-info.html",
			controller: 'SettingsInvoiceCtrl',
            data: {pageTitle: 'ตั้งค่าการออกเอกสาร', module:'settings-invoice' , main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/SettingsInvoiceCtrl.js'
                        ] 
                    });
                }],
				userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}
            }
        })
		/* Invoice Settings - Print Documents */
		.state("invoice-settings.invoice-print-documents", {
            url: "/invoice/doc-print",
            templateUrl: "views/settings/invoice-print-documents.html",
			controller: 'SettingsInvoiceCtrl',
            data: {pageTitle: 'ตั้งค่าการออกเอกสาร', module:'settings-invoice' , main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/SettingsInvoiceCtrl.js'
                        ] 
                    });
                }],
				userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}
            }
        })
		/* Invoice Settings - Related Images*/
		.state("invoice-settings.invoice-related-images", {
            url: "/invoice/images",
            templateUrl: "views/settings/invoice-related-images.html",
			controller: 'SettingsInvoiceCtrl',
            data: {pageTitle: 'ตั้งค่าการออกเอกสาร', module:'settings-invoice' , main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/SettingsInvoiceCtrl.js'
                        ] 
                    });
                }],
				userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}
            }
        })
		/* Invoice Settings - Personal Settings*/
		.state("invoice-settings.personal", {
            url: "/invoice/personal",
            templateUrl: "views/settings/personal.html",
			controller: 'SettingsPersonalCtrl',
            data: {pageTitle: 'ตั้งค่าการออกเอกสาร', module:'settings-personal' , main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/SettingsPersonalCtrl.js'
                        ] 
                    });
                }],
				$personal: function($getQuery){
                    return $getQuery.getPersonal('1');
                }
            }
        })		
		/* ph2.1 */
		//Invoice
        .state("invoice-income", {
            url: "/invoice/income",
            templateUrl: "views/invoice/income.html",
			controller: 'InvoiceIncomeCtrl',
            data: {pageTitle: 'เอกสารรายได้', module:'invoice-income' , main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                             'js/controllers/InvoiceIncomeCtrl.js'
                        ] 
                    });
                }]
				,userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}				
            }
        })
		/* ph2.1 */
		//Invoice
        .state("invoice-expense", {
            url: "/invoice/expense",
            templateUrl: "views/invoice/expense.html",
			controller: 'InvoiceExpenseCtrl',
            data: {pageTitle: 'เอกสารรายจ่าย', module:'invoice-expense' , main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                             'js/controllers/InvoiceExpenseCtrl.js'
                        ] 
                    });
                }]
				,userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}				
            }
        })
		/* ph2.1 */
		.state("invoice-income-manage", {
            url: "/invoice/income/manage/:form",
            templateUrl: "views/invoice/income-manage.html",
			params: {form : null},
			controller: 'InvoiceIncomeManageCtrl',
            data: {pageTitle: 'จัดการบิล', module:'invoice-income-manage', main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                             'js/controllers/InvoiceIncomeManageCtrl.js',
                        ] 
                    });
                }]
				,$invoices: function($getQuery, $stateParams){
                    return $getQuery.getInvoice("income_documents", $stateParams.form);
                }     
				,userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}
            }
        })
		/* ph2.1 */
		.state("invoice-expense-manage", {
            url: "/invoice/expense/manage/:form",
            //templateUrl: "views/invoice/expense-manage.html",
            templateUrl: function($stateParams){
				return "views/invoice/expense-manage."+ $stateParams.form +".html";
			},			
			params: {form : null},
			//controller: 'InvoiceIncomeManageCtrl',
			controllerProvider: function($stateParams){
				return "InvoiceExpenseManageCtrl."+ $stateParams.form;
			},			
            data: {pageTitle: 'จัดการบิล', module:'invoice-expense-manage', main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: function($ocLazyLoad, $stateParams) {
					let ctrl = "js/controllers/InvoiceExpenseManageCtrl."+ $stateParams.form +".js";
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                             //'js/controllers/InvoiceIncomeManageCtrl.js',
							ctrl
                        ] 
                    });
                }
				,$invoices: function($getQuery, $stateParams){
                    return $getQuery.getInvoice("expense_documents", $stateParams.form);
                }     
				,userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}
            }
        })		
		/* ph2.1 */
		.state("invoice-income-add", {
            url: "/invoice/income/add/:form",
            templateUrl: "views/invoice/income-add.html",
			controller: 'InvoiceIncomeAddCtrl',
            data: {
				pageTitle: 'จัดการเอกสารรายได้',
				module:'invoice-income-add' ,
				main_module: 'invoice',
				headerTitle : 'จัดการเอกสาร',
				redirect: 'invoice-income'
				},
            resolve: {
                deps: function($ocLazyLoad, $stateParams) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/InvoiceIncomeAddCtrl.js'
                        ] 
                    });
                }
				,$allItems: function($getQuery){
                    return $getQuery.getInvoiceItem();
                }                
				,$customers: function($getQuery){
                    return $getQuery.getAccounts('rcv');
                }
				,userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}
				,rcvMenus: function($getQuery){
					return $getQuery.getMenus('rcv');
				}
				,$referList: function($getQuery, $stateParams, userDefault){
                    return $getQuery.getInvoiceReference($stateParams.form, userDefault.VAT_item_type );
                }
            }
        })
		/* ph2.1 */
		.state("invoice-expense-add", {
            url: "/invoice/expense/add/:form",
            //templateUrl: "views/invoice/expense-add.html",
            templateUrl: function($stateParams){
				return "views/invoice/expense-add."+ $stateParams.form +".html";
			},
			//controller: 'InvoiceExpenseAddCtrl',
			controllerProvider: function($stateParams){
				return "InvoiceExpenseAddCtrl."+ $stateParams.form;
			},
            data: {pageTitle: 'จัดการเอกสารรายจ่าย', module:'invoice-expense-add' , main_module: 'invoice', headerTitle : 'จัดการเอกสาร', redirect: 'invoice-expense'},	
            resolve: {
                deps: function($ocLazyLoad, $stateParams) {
					let ctrl = "js/controllers/InvoiceExpenseAddCtrl."+ $stateParams.form +".js";
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
							ctrl
                        ]
                    });
                }
				,companyInfo: function($getQuery){
                    return $getQuery.getPersonal(1);
                }                
				,$customers: function($getQuery){
                    return $getQuery.getAccounts('exp');
                }
				,userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}
				,rcvMenus: function($getQuery){
					return $getQuery.getMenus('exp');
				}
				,$referList: function($getQuery, $stateParams){
                    return $getQuery.getInvoiceReference($stateParams.form);
                }			
            }
        })
		/* ph2.1 */
		.state("invoice-income-edit", {
            url: "/invoice/income/edit/:form/:invoiceId",
			params: {
				mongoId: null
			},
            templateUrl: "views/invoice/income-edit.html",
			controller: 'InvoiceIncomeEditCtrl',
            data: {pageTitle: 'จัดการบิล', module:'invoice-income-edit', main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                             'js/controllers/InvoiceIncomeEditCtrl.js',
                        ] 
                    });
                }]
				,invoiceData: function($getQuery,$stateParams,$invoiceService){
					//var id = $stateParams.mongoId == null ? $invoiceService.getInvoiceId : $stateParams.mongoId;
					return $getQuery.getInvoiceData("income_documents", $stateParams.mongoId, $stateParams.invoiceId);
				}
				,$allItems: function($getQuery){
                    return $getQuery.getInvoiceItem();
                }                
				,$customers: function($getQuery){
                    return $getQuery.getAccounts('rcv');
                }
				,userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}
				,rcvMenus: function($getQuery){
					return $getQuery.getMenus('rcv');
				}               
            }
        })
		/* ph2.1 */
		.state("invoice-expense-edit", {
            url: "/invoice/expense/edit/:form/:invoiceId",
			params: {
				mongoId: null
			},
            //templateUrl: "views/invoice/expense-edit.html",
            templateUrl: function($stateParams){
				return "views/invoice/expense-edit."+ $stateParams.form +".html";
			},
			controllerProvider: function($stateParams){
				return "InvoiceExpenseEditCtrl."+ $stateParams.form;
			},			
			//controller: 'InvoiceIncomeEditCtrl',
            data: {pageTitle: 'จัดการบิล', module:'invoice-expense-edit', main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: function($ocLazyLoad, $stateParams) {
					let ctrl = "js/controllers/InvoiceExpenseEditCtrl."+ $stateParams.form +".js";
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                             ctrl
                        ] 
                    });
                }
				,invoiceData: function($getQuery,$stateParams,$invoiceService){
					return $getQuery.getInvoiceData("expense_documents", $stateParams.mongoId, $stateParams.invoiceId);
					//return $getQuery.getInvoiceData("expense_documents", $stateParams.mongoId);
				}
				,$allItems: function($getQuery){
                    return $getQuery.getInvoiceItem();
                }                
				,$customers: function($getQuery){
                    return $getQuery.getAccounts('rcv');
                }
				,userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}
				,rcvMenus: function($getQuery){
					return $getQuery.getMenus('rcv');
				}               
            }
        })
		/* ph2.1 */
		.state("invoice-print", {
            url: "/invoice/print/:form/:invoiceId",
			params: {
				mongoId: null
			},
            templateUrl: "views/invoice/print.html",
			controller: 'InvoicePrintCtrl',
            data: {pageTitle: 'พิมพ์เอกสาร', module:'invoice-print', main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                             'js/controllers/InvoicePrintCtrl.js',
                        ] 
                    });
                }]
				,invoiceData: function($getQuery,$stateParams,$invoiceService){
					//var id = $stateParams.mongoId == null ? $invoiceService.getInvoiceId : $stateParams.mongoId;
					return $getQuery.getInvoiceData("income_documents", $stateParams.mongoId, $stateParams.invoiceId);
					//return $getQuery.getInvoiceData($stateParams.mongoId);
				}
				,$allItems: function($getQuery){
                    return $getQuery.getInvoiceItem();
                }                
				,$customers: function($getQuery){
                    return $getQuery.getAccounts('rcv');
                }
				,userDefault: function($getQuery){
					return $getQuery.getInvoiceSettings();
				}
				,rcvMenus: function($getQuery){
					return $getQuery.getMenus('rcv');
				}               
            }
        })		
		/* ph2.1 */
		.state("invoice-item", {
            url: "/invoice/item",
            templateUrl: "views/invoice/item.html",
			 controller: 'InvoiceItemCtrl',
            data: {pageTitle: 'รายการสินค้า', module:'invoice-item' , main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                             'js/controllers/InvoiceItemCtrl.js',
                        ] 
                    });
                }]
				,$allItems: function($getQuery){
                    return $getQuery.getInvoiceItem();
                }
            }
        })
		/* ph2.1 */
		.state("invoice-customer", {
            url: "/invoice/customer",
            templateUrl: "views/invoice/customer.html",
			 controller: 'InvoiceCustomerCtrl',
            data: {pageTitle: 'รายชื่อลูกค้า', module:'invoice-customer' , main_module: 'invoice', headerTitle : 'จัดการเอกสาร'},
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                             'js/controllers/InvoiceCustomerCtrl.js',
                        ] 
                    });
                }]
				,$customers: function($getQuery){
                    return $getQuery.getAccounts('rcv');
                }
            }
        })   			  		
		     
        // FAQ
        .state('help', {
            url: "/help",
            templateUrl: "views/help.html",            
            data: {pageTitle: 'ช่วยเหลือ', iClass: 'icon-question', module:'help' , main_module: 'mcf', headerTitle : 'กระแสเงินสด'},
            controller: "HelpController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            '../assets/pages/css/faq.min.css',
                            '../assets/global/plugins/jquery.blockui.min.js',
                            'js/controllers/HelpController.js'
                        ] 
                    });
                }]
            }
        })


        // Blank Page
        .state('blank', {
            url: "/blank",
            templateUrl: "views/blank.html",            
            data: {pageTitle: 'Blank Page Template'},
            controller: "BlankController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before a LINK element with this ID. Dynamic CSS files must be loaded between core and theme css files
                        files: [
                            'js/controllers/BlankController.js'
                        ] 
                    });
                }]
            }
        })

        // AngularJS plugins
        .state('fileupload', {
            url: "/file_upload.html",
            templateUrl: "views/file_upload.html",
            data: {pageTitle: 'AngularJS File Upload'},
            controller: "GeneralPageController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load([{
                        name: 'angularFileUpload',
                        files: [
                            '../assets/global/plugins/angularjs/plugins/angular-file-upload/angular-file-upload.min.js',
                        ] 
                    }, {
                        name: 'MetronicApp',
                        files: [
                            'js/controllers/GeneralPageController.js'
                        ]
                    }]);
                }]
            }
        })

        // UI Select
        .state('uiselect', {
            url: "/ui_select.html",
            templateUrl: "views/ui_select.html",
            data: {pageTitle: 'AngularJS Ui Select'},
            controller: "UISelectController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load([{
                        name: 'ui.select',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before '#ng_load_plugins_before'
                        files: [
                            '../assets/global/plugins/angularjs/plugins/ui-select/select.min.css',
                            '../assets/global/plugins/angularjs/plugins/ui-select/select.min.js'
                        ] 
                    }, {
                        name: 'MetronicApp',
                        files: [
                            'js/controllers/UISelectController.js'
                        ] 
                    }]);
                }]
            }
        })

        // UI Bootstrap
        .state('uibootstrap', {
            url: "/ui_bootstrap.html",
            templateUrl: "views/ui_bootstrap.html",
            data: {pageTitle: 'AngularJS UI Bootstrap'},
            controller: "GeneralPageController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load([{
                        name: 'MetronicApp',
                        files: [
                            'js/controllers/GeneralPageController.js'
                        ] 
                    }]);
                }] 
            }
        })

        // Tree View
        .state('tree', {
            url: "/tree",
            templateUrl: "views/tree.html",
            data: {pageTitle: 'jQuery Tree View'},
            controller: "GeneralPageController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load([{
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before '#ng_load_plugins_before'
                        files: [
                            '../assets/global/plugins/jstree/dist/themes/default/style.min.css',

                            '../assets/global/plugins/jstree/dist/jstree.min.js',
                            '../assets/pages/scripts/ui-tree.min.js',
                            'js/controllers/GeneralPageController.js'
                        ] 
                    }]);
                }] 
            }
        })     

        // Form Tools
        .state('formtools', {
            url: "/form-tools",
            templateUrl: "views/form_tools.html",
            data: {pageTitle: 'Form Tools'},
            controller: "GeneralPageController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load([{
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before '#ng_load_plugins_before'
                        files: [
                            '../assets/global/plugins/bootstrap-fileinput/bootstrap-fileinput.css',
                            '../assets/global/plugins/bootstrap-switch/css/bootstrap-switch.min.css',
                            '../assets/global/plugins/bootstrap-markdown/css/bootstrap-markdown.min.css',
                            '../assets/global/plugins/typeahead/typeahead.css',

                            '../assets/global/plugins/fuelux/js/spinner.min.js',
                            '../assets/global/plugins/bootstrap-fileinput/bootstrap-fileinput.js',
                            '../assets/global/plugins/jquery-inputmask/jquery.inputmask.bundle.min.js',
                            '../assets/global/plugins/jquery.input-ip-address-control-1.0.min.js',
                            '../assets/global/plugins/bootstrap-pwstrength/pwstrength-bootstrap.min.js',
                            '../assets/global/plugins/bootstrap-switch/js/bootstrap-switch.min.js',
                            '../assets/global/plugins/bootstrap-maxlength/bootstrap-maxlength.min.js',
                            '../assets/global/plugins/bootstrap-touchspin/bootstrap.touchspin.js',
                            '../assets/global/plugins/typeahead/handlebars.min.js',
                            '../assets/global/plugins/typeahead/typeahead.bundle.min.js',
                            '../assets/pages/scripts/components-form-tools-2.min.js',

                            'js/controllers/GeneralPageController.js'
                        ] 
                    }]);
                }] 
            }
        })        

        // Date & Time Pickers
        .state('pickers', {
            url: "/pickers",
            templateUrl: "views/pickers.html",
            data: {pageTitle: 'Date & Time Pickers'},
            controller: "GeneralPageController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load([{
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before '#ng_load_plugins_before'
                        files: [
                            '../assets/global/plugins/clockface/css/clockface.css',
                            '../assets/global/plugins/bootstrap-datepicker/css/bootstrap-datepicker3.min.css',
                            '../assets/global/plugins/bootstrap-datepicker/js/bootstrap-datepicker.min.js',
                            '../assets/global/plugins/bootstrap-timepicker/css/bootstrap-timepicker.min.css',
                            '../assets/global/plugins/bootstrap-colorpicker/css/colorpicker.css',
                            '../assets/global/plugins/bootstrap-datetimepicker/css/bootstrap-datetimepicker.min.css',

                            '../assets/global/plugins/bootstrap-datepicker/js/bootstrap-datepicker.min.js',
                            '../assets/global/plugins/bootstrap-datepicker/locales/bootstrap-datepicker.th.min.js',
                            '../assets/global/plugins/bootstrap-timepicker/js/bootstrap-timepicker.min.js',
                            '../assets/global/plugins/clockface/js/clockface.js',
                            '../assets/global/plugins/bootstrap-colorpicker/js/bootstrap-colorpicker.js',
                            '../assets/global/plugins/bootstrap-datetimepicker/js/bootstrap-datetimepicker.min.js',

                            '../assets/pages/scripts/components-date-time-pickers.min.js',

                            'js/controllers/GeneralPageController.js'
                        ] 
                    }]);
                }] 
            }
        })

        // Custom Dropdowns
        .state('dropdowns', {
            url: "/dropdowns",
            templateUrl: "views/dropdowns.html",
            data: {pageTitle: 'Custom Dropdowns'},
            controller: "GeneralPageController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load([{
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before '#ng_load_plugins_before'
                        files: [
                            '../assets/global/plugins/bootstrap-select/css/bootstrap-select.min.css',
                            '../assets/global/plugins/select2/css/select2.min.css',
                            '../assets/global/plugins/select2/css/select2-bootstrap.min.css',

                            '../assets/global/plugins/bootstrap-select/js/bootstrap-select.min.js',
                            '../assets/global/plugins/select2/js/select2.full.min.js',

                            '../assets/pages/scripts/components-bootstrap-select.min.js',
                            '../assets/pages/scripts/components-select2.min.js',

                            'js/controllers/GeneralPageController.js'
                        ] 
                    }]);
                }] 
            }
        }) 

        // Advanced Datatables
        .state('datatablesmanaged', {
            url: "/datatables/managed.html",
            templateUrl: "views/datatables/managed.html",
            data: {pageTitle: 'Advanced Datatables'},
            controller: "GeneralPageController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before '#ng_load_plugins_before'
                        files: [                             
                            '../assets/global/plugins/datatables/datatables.min.css', 
                            '../assets/global/plugins/datatables/plugins/bootstrap/datatables.bootstrap.css',

                            '../assets/global/plugins/datatables/datatables.all.min.js',

                            '../assets/pages/scripts/table-datatables-managed.min.js',

                            'js/controllers/GeneralPageController.js'
                        ]
                    });
                }]
            }
        })

        // Ajax Datetables
        .state('datatablesajax', {
            url: "/datatables/ajax.html",
            templateUrl: "views/datatables/ajax.html",
            data: {pageTitle: 'Ajax Datatables'},
            controller: "GeneralPageController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',
                        insertBefore: '#ng_load_plugins_before', // load the above css files before '#ng_load_plugins_before'
                        files: [
                            '../assets/global/plugins/datatables/datatables.min.css', 
                            '../assets/global/plugins/datatables/plugins/bootstrap/datatables.bootstrap.css',
                            '../assets/global/plugins/bootstrap-datepicker/css/bootstrap-datepicker3.min.css',

                            '../assets/global/plugins/datatables/datatables.all.min.js',
                            '../assets/global/plugins/bootstrap-datepicker/js/bootstrap-datepicker.min.js',
                            '../assets/global/scripts/datatable.js',

                            'js/scripts/table-ajax.js',
                            'js/controllers/GeneralPageController.js'
                        ]
                    });
                }]
            }
        })

        // User Profile
        .state("profile", {
            url: "/profile",
            templateUrl: "views/profile/main.html",
            data: {pageTitle: 'User Profile'},
            controller: "UserProfileController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({
                        name: 'MetronicApp',  
                        insertBefore: '#ng_load_plugins_before', // load the above css files before '#ng_load_plugins_before'
                        files: [
                            '../assets/global/plugins/bootstrap-fileinput/bootstrap-fileinput.css',
                            '../assets/pages/css/profile.css',
                            
                            '../assets/global/plugins/jquery.sparkline.min.js',
                            '../assets/global/plugins/bootstrap-fileinput/bootstrap-fileinput.js',

                            '../assets/pages/scripts/profile.min.js',

                            'js/controllers/UserProfileController.js'
                        ]                    
                    });
                }]
            }
        })

        // User Profile Dashboard
        .state("profile.dashboard", {
            url: "/dashboard",
            templateUrl: "views/profile/dashboard.html",
            data: {pageTitle: 'User Profile'}
        })

        // User Profile Account
        .state("profile.account", {
            url: "/account",
            templateUrl: "views/profile/account.html",
            data: {pageTitle: 'User Account'}
        })

        // User Profile Help
        .state("profile.help", {
            url: "/help",
            templateUrl: "views/profile/help.html",
            data: {pageTitle: 'User Help'}      
        })

        // Todo
        .state('todo', {
            url: "/todo",
            templateUrl: "views/todo.html",
            data: {pageTitle: 'Todo'},
            controller: "TodoController",
            resolve: {
                deps: ['$ocLazyLoad', function($ocLazyLoad) {
                    return $ocLazyLoad.load({ 
                        name: 'MetronicApp',  
                        insertBefore: '#ng_load_plugins_before', // load the above css files before '#ng_load_plugins_before'
                        files: [
                            '../assets/global/plugins/bootstrap-datepicker/css/bootstrap-datepicker3.min.css',
                            '../assets/apps/css/todo-2.css',
                            '../assets/global/plugins/select2/css/select2.min.css',
                            '../assets/global/plugins/select2/css/select2-bootstrap.min.css',

                            '../assets/global/plugins/select2/js/select2.full.min.js',
                            
                            '../assets/global/plugins/bootstrap-datepicker/js/bootstrap-datepicker.min.js',

                            '../assets/apps/scripts/todo-2.min.js',

                            'js/controllers/TodoController.js'  
                        ]                    
                    });
                }]
            }
        })
}]);



/* Init global settings and run the app */

MetronicApp.run(["$rootScope", "$cookies","settings", "$state", "$http" ,function($rootScope, $cookies,settings, $state, $http, AuthService) {
    $rootScope.$state = $state; // state to be accessed from view
    $rootScope.$settings = settings; // state to be accessed from view
    $rootScope.settings = settings; // state to be accessed from view
	$rootScope.authenticate = true; 
	var cookiesSession =  $cookies.get('mcf_data_session');
	
		$http.defaults.headers.common["X-Requested-With"] = "XMLHttpRequest";
		$http.defaults.headers.common["X-Requested-By"] = "MCFApplication";	
	$http.get('php_data/getUserSessions.php?business_id=1&session_id='+cookiesSession)
		.success(function(data2) {
			if(data2.success)
			{
				$rootScope.userId = data2.userID;
			} 
		})
	.error(function(err) {console.log(err);} );
		$rootScope.$on("$stateChangeStart", function(event, toState, fromState){
		$('.toast-close-button').click();
		if($rootScope.authenticate && toState) {
			var permissionRequest = toState.data.module;
			var requestedState = toState.name;				
			if(requestedState == 'invoice-income-add' || requestedState == 'invoice-expense-add'){
				//event.preventDefault();
				//console.log(toState.name);
				let jsonString = JSON.stringify($rootScope.sessionUserData);
				//event.preventDefault();
				$http.get('php_data/getInvoiceCount.php?jsonString='+jsonString).success(
					function(dat){
						//console.log(dat);
						if(dat.valid == false){
							$('#expiredModal').modal({
								backdrop: 'static',
								show: 'true'
							});
							if(toState.data.redirect)
							{
								$state.transitionTo(toState.data.redirect);
							}
							else
							{
								$state.transitionTo("home");
							}
							
						}
				});
			}
			else if(
				requestedState !== "invoice-dashboard" && 
				requestedState !== "invoice-settings" && 
				requestedState !== "invoice-settings.invoice-documents-info" && 
				requestedState !== "invoice-settings.invoice-print-documents" && 
				requestedState !== "invoice-settings.invoice-related-images" && 
				requestedState !== "invoice-settings.personal" && 
				requestedState !== "invoice-income" && 
				requestedState !== "invoice-expense" && 
				requestedState !== "invoice-income-manage" && 
				requestedState !== "invoice-expense-manage" && 
				requestedState !== "invoice-income-add" && 
				requestedState !== "invoice-expense-add" &&
 				requestedState !== "invoice-income-edit" && 
				requestedState !== "invoice-expense-edit" && 
				requestedState !== "invoice-print" && 
				requestedState !== "invoice-item" && 
				requestedState !== "invoice-customer" && 
				requestedState !== "expired" && 
				requestedState !== "home" && 
				requestedState !== "dashboard" && 
				requestedState.indexOf("settings") < 0 && 
				requestedState.indexOf("report") < 0 && 
				$rootScope.userId)
			{ 
				//event.preventDefault();
				$http.get('php_data/checkPermissions.php?business_id=1&user_id='+$rootScope.userId+'&permission='+permissionRequest)
						.success(function(data) {
							if(!data.success )
							{
                                $state.transitionTo("home");
                                swal({
				                	title: 'ไม่มีสิทธิ์ในการเข้าใช้งาน',
					                text: 'คุณไม่สามารถเข้าใช้งานหน้าต่างนี้ได้ หากต้องการเข้าใช้งานกรุณาติดต่อกับพนักงานที่สามารถตั้งค่าการใช้งานภายในกิจการของคุณค่ะ'
				                });
							}
	
						})
						.error(function(err) {console.log(err);} );
			}

		}
		});
	//}
	//}


}]);